@@ -13,14 +13,14 @@ class ErrorReportingIssue(unittest.TestCase):
     endpoint.
     """
 
-    @unittest.skipIf(True, "Fragile test - we need local data to consistently reproduce")
+    @unittest.skipIf(False, "Fragile test - we need local data to consistently reproduce")
     def test_messages(self):
         """ Test failures with no reasons supplied """
         shex = os.path.join(data_dir, 'biolink-model.shex')
         sparql = os.path.join(data_dir, 'biolink_model.sparql')
         messages = StringIO()
         with redirect_stdout(messages):
-            evaluate_cli(f'-ss -sq {sparql}  http://graphdb.dumontierlab.com/repositories/ncats-red-kg {shex} -ut')
+            evaluate_cli(f'-ss -sq {sparql}  http://graphdb.dumontierlab.com/repositories/ncats-red-kg {shex} -ut -pb')
         for line in messages.getvalue().split('\n'):
             self.assertFalse(line.strip().endswith('Reason:'))
 
